@@ -1,6 +1,6 @@
 package Catalyst::View::Template::Lace;
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 
 use Module::Runtime;
 use Catalyst::View::Template::Lace::Renderer;
@@ -134,6 +134,22 @@ Used in a controller:
 
     __PACKAGE__->meta->make_immutable;
 
+A Template may also contain components which are reusable blocks of template
+functionality and which refer to other Catalyst Views in your application:
+
+    <view-master title='Homepage'>
+      <view-header navbar_section='home'/>
+        <section>
+          <p>You are doomed to discover you can never recover from the narcolyptic
+          country in which you once stood, where the fires alway burning but there's
+          never enough wood</p>
+        </section>
+      <view-footer copyright='$.copy' />
+    </view-master>
+
+Such components can wrap your main content or even other component, and they can
+accept arguments.  See L<Catalyst::View::Template::Lace::Tutorial> for more details.
+
 =head1 DESCRIPTION
 
 B<NOTE> I consider this an early access release.  Code and API here is subject
